pub struct MockChainTipSender {
best_tip_height: Sender<Option<Height>>,
best_tip_hash: Sender<Option<Hash>>,
best_tip_block_time: Sender<Option<DateTime<Utc>>>,
estimated_distance_to_network_chain_tip: Sender<Option<HeightDiff>>,
}Expand description
A sender to sets the values read by a MockChainTip.
Fields
best_tip_height: Sender<Option<Height>>A sender that sets the best_tip_height of a MockChainTip.
best_tip_hash: Sender<Option<Hash>>A sender that sets the best_tip_hash of a MockChainTip.
best_tip_block_time: Sender<Option<DateTime<Utc>>>A sender that sets the best_tip_block_time of a MockChainTip.
estimated_distance_to_network_chain_tip: Sender<Option<HeightDiff>>A sender that sets the estimate_distance_to_network_chain_tip of a MockChainTip.
Implementations
Sourceimpl MockChainTipSender
impl MockChainTipSender
Sourcepub fn send_best_tip_height(&self, height: impl Into<Option<Height>>)
pub fn send_best_tip_height(&self, height: impl Into<Option<Height>>)
Send a new best tip height to the MockChainTip.
Sourcepub fn send_best_tip_hash(&self, hash: impl Into<Option<Hash>>)
pub fn send_best_tip_hash(&self, hash: impl Into<Option<Hash>>)
Send a new best tip hash to the MockChainTip.
Sourcepub fn send_best_tip_block_time(
&self,
block_time: impl Into<Option<DateTime<Utc>>>,
)
pub fn send_best_tip_block_time( &self, block_time: impl Into<Option<DateTime<Utc>>>, )
Send a new best tip block time to the MockChainTip.
Sourcepub fn send_estimated_distance_to_network_chain_tip(
&self,
distance: impl Into<Option<HeightDiff>>,
)
pub fn send_estimated_distance_to_network_chain_tip( &self, distance: impl Into<Option<HeightDiff>>, )
Send a new estimated distance to network chain tip to the MockChainTip.